@@ -22,20 +22,20 @@ LANGUAGES_EXTENSIONS = {
     '.bash': 'bash',
     '.c': 'c',
     '.cpp': 'cpp',
-    '.csharp': 'c#',
+    '.csharp': 'csharp',
     '.css': 'css',
     '.go': 'go',
     '.html': 'html',
     '.java': 'java',
-    '.js': 'javascript',
+    '.js': 'js',
     '.json': 'json',
     '.lua': 'lua',
-    '.md': 'markdown',
+    '.md': 'md',
     '.php': 'php',
     '.txt': 'plaintext',
     '':'plaintext',
     '.py': 'python',
-    '.rb': 'ruby',
+    '.rb': 'rb',
 }
 
 THEMES = {
